==> org-lsst-ccs-subsystem-comcamvacuum-buses-1.0.7-sources.jar: org/lsst/ccs/subsystem/comcamvacuum/data/VacSysState.java <==
package org.lsst.ccs.subsystem.comcamvacuum.data;

import org.lsst.ccs.subsystem.comcamvacuum.constants.ConditionState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.DeviceState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.SwitchState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.SwitchEnable;
import org.lsst.ccs.subsystem.comcamvacuum.constants.VacuumState;
import java.io.Serializable;

/**
 *  Contains the state of the vacuum subsystem
 *
 *  @author Owen Saxton
 */
public class VacSysState implements Serializable {
    
    public static final String KEY = "ComCamVacuumState";
    public static final int
        SW_CRYO_TURBO     = 0,
        SW_CRYO_ION_PUMP1 = 1,
//        SW_CRYO_ION_PUMP2 = 2,
//        SW_CRYO_ION_PUMP3 = 3,
//        SW_CRYO_ION_PUMP4 = 4,
//        SW_CRYO_ION_PUMP5 = 5,
//        SW_CRYO_ION_PUMP6 = 6,
        SW_CRYO_VALVE     = 2,
        SW_HX_TURBO       = 3,
        SW_HX_ION_PUMP1   = 4,
//        SW_HX_ION_PUMP2   = 5,
    //        SW_HX_VALVE       = 5,
        SW_OR_ION_PUMP    = 5,
    //        SW_OR_FPP_VALVE   = 7,
    //        SW_OR_FH_VALVE    = 8,
    //        SW_OR_L3H_VALVE   = 9,
    //        SW_OR_L3_VALVE    = 10,
    //        SW_KOOLANCE       = 11,
        SW_CRYOTEL_CRYO   = 6,
        SW_CRYOTEL_COLD1  = 7,
        SW_CRYOTEL_COLD2  = 8,
    //        SW_CRYOTEL_PWR    = 15,
    //        SW_KOOLCOLD       = 16,
        NUM_SWITCHES      = 9;
    public static final int
        COND_CR_VACUUM   = 0,
        COND_CR_GATE_NFC = 1,
        COND_CR_GATE_AO  = 2,
        COND_CR_PUMP     = 3,
        COND_HX_VACUUM   = 4,
        COND_HX_GATE_NFC = 5,
        COND_HX_GATE_AO  = 6,
        COND_HX_PUMP     = 7,
        NUM_CONDITIONS   = 8;

    private int tickMillis;           // Data status update period (ms)
    private VacuumState vacuumState = VacuumState.UNKNOWN;  // The vacuum state
    private int switchMask;           // Bit mask of defined switches
    private int conditionMask;        // Bit mask of defined conditions
    private final SwitchState[] switchState = new SwitchState[NUM_SWITCHES];  // Switch state array
    private final SwitchEnable[] switchEnable = new SwitchEnable[NUM_SWITCHES];  // Switch enable array
    private final DeviceState[] deviceState = new DeviceState[NUM_SWITCHES];  // Extra device state array
    private final ConditionState[] conditionState = new ConditionState[NUM_CONDITIONS];
    
    public void setTickMillis(int value) {
        tickMillis = value;
    }

    public int getTickMillis() {
        return tickMillis;
    }

    public void setVacuumState(VacuumState value) {
        vacuumState = value;
    }

    public VacuumState getVacuumState() {
        return vacuumState;
    }

    public void addSwitch(int sw) {
        switchMask |= (1 << sw);
    }

    public boolean hasSwitch(int sw) {
        return (switchMask & (1 << sw)) != 0;
    }

    public void setSwitchState(int sw, SwitchState state) {
        switchState[sw] = state;
    }

    public SwitchState getSwitchState(int sw) {
        return switchState[sw];
    }

    public void setSwitchEnable(int sw, SwitchEnable enable) {
        switchEnable[sw] = enable;
    }

    public SwitchEnable getSwitchEnable(int sw) {
        return switchEnable[sw];
    }

    public void setDeviceState(int sw, DeviceState state) {
        deviceState[sw] = state;
    }

    public DeviceState getDeviceState(int sw) {
        return deviceState[sw];
    }

    public void addCondition(int cond) {
        conditionMask |= (1 << cond);
    }

    public boolean hasCondition(int cond) {
        return (conditionMask & (1 << cond)) != 0;
    }

    public void setCondition(int cond, ConditionState state) {
        conditionState[cond] = state;
    }

    public ConditionState getCondition(int cond) {
        return conditionState[cond];
    }

    private static final long serialVersionUID = 2081368367194546251L;
}

==> org-lsst-ccs-subsystem-comcamvacuum-buses-1.0.21-sources.jar: org/lsst/ccs/subsystem/comcamvacuum/data/VacSysState.java <==
package org.lsst.ccs.subsystem.comcamvacuum.data;

import org.lsst.ccs.subsystem.comcamvacuum.constants.ConditionState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.LatchState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.PLCState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.DeviceState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.SwitchState;
import org.lsst.ccs.subsystem.comcamvacuum.constants.SwitchEnable;
import org.lsst.ccs.subsystem.comcamvacuum.constants.VacuumState;
import java.io.Serializable;

/**
 *  Contains the state of the vacuum subsystem
 *
 *  @author Owen Saxton
 */
public class VacSysState implements Serializable {
    
    public static final String KEY = "ComCamVacuumState";
    public static final int
        SW_CRYO_TURBO     = 0,
        SW_CRYO_ION_PUMP1 = 1,
//        SW_CRYO_ION_PUMP2 = 2,
//        SW_CRYO_ION_PUMP3 = 3,
//        SW_CRYO_ION_PUMP4 = 4,
//        SW_CRYO_ION_PUMP5 = 5,
//        SW_CRYO_ION_PUMP6 = 6,
        SW_CRYO_VALVE     = 2,
        SW_HX_TURBO       = 3,
        SW_HX_ION_PUMP1   = 4,
//        SW_HX_ION_PUMP2   = 5,
    //        SW_HX_VALVE       = 5,
        SW_OR_ION_PUMP    = 5,
    //        SW_OR_FPP_VALVE   = 7,
    //        SW_OR_FH_VALVE    = 8,
    //        SW_OR_L3H_VALVE   = 9,
    //        SW_OR_L3_VALVE    = 10,
    //        SW_KOOLANCE       = 11,
        SW_CRYOTEL_CRYO   = 6,
        SW_CRYOTEL_COLD1  = 7,
        SW_CRYOTEL_COLD2  = 8,
    //        SW_CRYOTEL_PWR    = 15,
    //        SW_KOOLCOLD       = 16,
        NUM_SWITCHES      = 9;

    public static final int
        LATCH_CR_VACUUM   = 0,
        LATCH_CR_GATE_NFC = 1,
        LATCH_CR_GATE_AO  = 2,
        LATCH_CR_PUMP     = 3,
        LATCH_HX_VACUUM   = 4,
        LATCH_HX_GATE_NFC = 5,
        LATCH_HX_GATE_AO  = 6,
        LATCH_HX_PUMP     = 7,
        NUM_LATCHES       = 8;

    public static final int
        COND_CR_FORELINE_VAC = 0,
        COND_CR_TRB_PUMP_OFF = 1,
        COND_CR_TRB_PRESS_10 = 2,
        COND_CR_VACUUM_01    = 3,
        COND_CR_VACUUM_001   = 4,
        COND_HX_FORELINE_VAC = 5,
        COND_HX_TURBO_OFF    = 6,
        COND_HX_TRB_PRESS_10 = 7,
        COND_HX_VACUUM_01    = 8,
        COND_HX_VACUUM_001   = 9,
        COND_OR_FPP_VALVE    = 10,
        COND_OR_FH_VALVE     = 11,
        COND_OR_L3H_VALVE    = 12,
        COND_OR_L3_VALVE     = 13,
        NUM_CONDITIONS       = 14;

    /*
    public static final int
        COND_CR_VACUUM   = 0,
        COND_CR_GATE_NFC = 1,
        COND_CR_GATE_AO  = 2,
        COND_CR_PUMP     = 3,
        COND_HX_VACUUM   = 4,
        COND_HX_GATE_NFC = 5,
        COND_HX_GATE_AO  = 6,
        COND_HX_PUMP     = 7,
        NUM_CONDITIONS   = 8;
    */

    private int tickMillis;           // Data status update period (ms)
    private VacuumState vacuumState = VacuumState.UNKNOWN;  // The vacuum state
    private PLCState plcState = PLCState.ALIVE;  // The PLC state
    private int switchMask;           // Bit mask of defined switches
    private int conditionMask;        // Bit mask of defined conditions
    private final SwitchState[] switchState = new SwitchState[NUM_SWITCHES];  // Switch state array
    private final SwitchEnable[] switchEnable = new SwitchEnable[NUM_SWITCHES];  // Switch enable array
    private final DeviceState[] deviceState = new DeviceState[NUM_SWITCHES];  // Extra device state array
    private final ConditionState[] conditionState = new ConditionState[NUM_CONDITIONS];


    private int latchMask;            // Bit mask of defined latched conditions
    private final LatchState[] latchState = new LatchState[NUM_LATCHES];  // Latched PLC conditions array


    
    public void setTickMillis(int value) {
        tickMillis = value;
    }

    public int getTickMillis() {
        return tickMillis;
    }

    public void setVacuumState(VacuumState value) {
        vacuumState = value;
    }

    public VacuumState getVacuumState() {
        return vacuumState;
    }

    public void setPlcState(PLCState value) {
        plcState = value;
    }

    public PLCState getPlcState() {
        return plcState;
    }

    public void addSwitch(int sw) {
        switchMask |= (1 << sw);
    }

    public boolean hasSwitch(int sw) {
        return (switchMask & (1 << sw)) != 0;
    }

    public void setSwitchState(int sw, SwitchState state) {
        switchState[sw] = state;
    }

    public SwitchState getSwitchState(int sw) {
        return switchState[sw];
    }

    public void setSwitchEnable(int sw, SwitchEnable enable) {
        switchEnable[sw] = enable;
    }

    public SwitchEnable getSwitchEnable(int sw) {
        return switchEnable[sw];
    }

    public void addLatch(int latch) {
        latchMask |= (1 << latch);
    }

    public boolean hasLatch(int latch) {
        return (latchMask & (1 << latch)) != 0;
    }

    public void setLatch(int latch, LatchState state) {
        latchState[latch] = state;
    }

    public LatchState getLatch(int latch) {
        return latchState[latch];
    }

    public void setDeviceState(int sw, DeviceState state) {
        deviceState[sw] = state;
    }

    public DeviceState getDeviceState(int sw) {
        return deviceState[sw];
    }

    public void addCondition(int cond) {
        conditionMask |= (1 << cond);
    }

    public boolean hasCondition(int cond) {
        return (conditionMask & (1 << cond)) != 0;
    }

    public void setCondition(int cond, ConditionState state) {
        conditionState[cond] = state;
    }

    public ConditionState getCondition(int cond) {
        return conditionState[cond];
    }

    private static final long serialVersionUID = 2081368367194546251L;
}
